..
    Copyright (C) 2023 CERN.

    Invenio-Notifications is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.


API Docs
========

.. automodule:: invenio_notifications.ext
   :members:
